@@ -450,7 +450,7 @@ static bool create_bluray_virtualfile(BLURAY *bd, const BLURAY_TITLE_INFO* ti, c
                  title_idx + 1,
                  replace_all(format_duration(duration), ":", "-").c_str(),
                  is_main_title ? "+" : "",
-                 ffmpeg_format[0].fileext().c_str()); // can safely assume this is a video format
+                 ffmpeg_format[FORMAT::VIDEO].fileext().c_str()); // can safely assume this is a video format
     }
     else
     {
@@ -467,18 +467,18 @@ static bool create_bluray_virtualfile(BLURAY *bd, const BLURAY_TITLE_INFO* ti, c
                  chapter_idx + 1,
                  replace_all(format_duration(duration), ":", "-").c_str(),
                  is_main_title ? "+" : "",
-                 ffmpeg_format[0].fileext().c_str()); // can safely assume this is a video format
+                 ffmpeg_format[FORMAT::VIDEO].fileext().c_str()); // can safely assume this is a video format
 
     }
 
     LPVIRTUALFILE virtualfile = nullptr;
-    if (!ffmpeg_format[0].is_multiformat())
+    if (!ffmpeg_format[FORMAT::VIDEO].is_multiformat())
     {
-        virtualfile = insert_file(VIRTUALTYPE_BLURAY, path + title_buf, statbuf);
+        virtualfile = insert_file(VIRTUALTYPE::BLURAY, path + title_buf, statbuf);
     }
     else
     {
-        virtualfile = insert_dir(VIRTUALTYPE_BLURAY, path + title_buf, statbuf);
+        virtualfile = insert_dir(VIRTUALTYPE::BLURAY, path + title_buf, statbuf);
     }
 
     if (virtualfile == nullptr)
