@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2023 by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2024 by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2024 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifndef FFMPEG_FRAME_H
@@ -58,7 +58,7 @@ public:
      * @param[in] frame - Pointer to source AVFrame struct.
      * @note Do not declare explicit, breaks use in std::variant
      */
-    FFmpeg_Frame(const AVFrame * frame);
+    FFmpeg_Frame(const AVFrame * frame);    // cppcheck-suppress noExplicitConstructor
     /**
      * @brief Destruct FFmpeg_Frame object.
      */
