@@ -97,16 +97,12 @@
  * \include COPYING.CC0
  */
 
-#define FUSE_USE_VERSION 26             /**< @brief Requested minimum FUSE version */
+#define FUSE_USE_VERSION 30             /**< @brief Requested minimum FUSE version */
 
 #ifdef __cplusplus
 extern "C" {
 #endif
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
-#pragma GCC diagnostic ignored "-Wsign-conversion"
-#include <fuse.h>
-#pragma GCC diagnostic pop
+#include <fuse3/fuse.h>
 #ifdef __cplusplus
 }
 #endif
@@ -120,44 +116,43 @@ extern "C" {
   *
   * @brief Hardware acceleration types.
   */
-typedef enum HWACCELAPI
+enum class HWACCELAPI
 {
-    HWACCELAPI_NONE,
-    HWACCELAPI_VAAPI,               /**< Intel: VAAPI */
+    NONE,
+    VAAPI,                  /**< Intel: VAAPI */
 
-    HWACCELAPI_MMAL,                /**< Raspberry: MMAL */
-    HWACCELAPI_OMX,                 /**< Raspberry: OpenMAX */
+    MMAL,                   /**< Raspberry: MMAL */
+    OMX,                    /**< Raspberry: OpenMAX */
 
     // Additional formats
 #if 0
-    HWACCELAPI_CUDA,                /**< Nividia: CUDA    to be added */
-    HWACCELAPI_V4L2M2M,             /**< v4l2 mem to mem  to be added */
-    HWACCELAPI_VDPAU,               /**< VDPAU            to be added */
-    HWACCELAPI_QSV,                 /**< QSV              to be added */
-    HWACCELAPI_OPENCL,              /**< OPENCL           to be added */
+    CUDA,                   /**< Nividia: CUDA    to be added */
+    V4L2M2M,                /**< v4l2 mem to mem  to be added */
+    VDPAU,                  /**< VDPAU            to be added */
+    QSV,                    /**< QSV              to be added */
+    OPENCL,                 /**< OPENCL           to be added */
 #if HAVE_VULKAN_HWACCEL
-    HWACCELAPI_VULKAN,              /**< VULKAN           to be added */
+    VULKAN,                 /**< VULKAN           to be added */
 #endif // HAVE_VULKAN_HWACCEL
 #if __APPLE__
     // MacOS acceleration APIs not supported
-    HWACCELAPI_VIDEOTOOLBOX,        /**< VIDEOTOOLBOX     not supported */
+    VIDEOTOOLBOX,           /**< VIDEOTOOLBOX     not supported */
 #endif
 #if __ANDROID__
     // Android acceleration APIs not supported
-    HWACCELAPI_MEDIACODEC,          /**< MediaCodec API   not supported */
+    MEDIACODEC,             /**< MediaCodec API   not supported */
 #endif
 #if _WIN32
     // Windows acceleration APIs not supported
-    HWACCELAPI_DRM,                 /**< DRM              not supported */
-    HWACCELAPI_DXVA2,               /**< DXVA2            not supported */
-    HWACCELAPI_D3D11VA,             /**< D3D11VA          not supported */
+    DRM,                    /**< DRM              not supported */
+    DXVA2,                  /**< DXVA2            not supported */
+    D3D11VA,                /**< D3D11VA          not supported */
 #endif
 #endif
-} HWACCELAPI;
+};
 
 typedef std::multimap<AVCodecID, int> HWACCEL_BLOCKED_MAP;      /**< @brief Map command line option to AVCodecID */
 
-// Format
 extern FFMPEGFS_FORMAT_ARR ffmpeg_format;                       /**< @brief Two FFmpegfs_Format infos, 0: video file, 1: audio file */
 
 /**
@@ -177,14 +172,14 @@ extern struct FFMPEGFS_PARAMS
      * @brief Check for smart transcode mode
      * @return true if smart transcode is active, false if not
      */
-    bool                smart_transcode() const;
+    bool                    smart_transcode() const;
 
     /**
      * @brief Get FFmpegfs_Format for a virtual file.
      * @param[in] virtualfile - VIRTUALFILE struct of a file.
      * @return On success, returns pointer to format. On error, returns nullptr.
      */
-    const FFmpegfs_Format *current_format(LPCVIRTUALFILE virtualfile) const;
+    const FFmpegfs_Format * current_format(LPCVIRTUALFILE virtualfile) const;
 
     /**
      * @brief Make copy from other FFMPEGFS_PARAMS object.
@@ -257,8 +252,8 @@ extern struct FFMPEGFS_PARAMS
     int                     m_decoding_errors;              /**< @brief Break transcoding on decoding error */
     int                     m_min_dvd_chapter_duration;     /**< @brief Min. DVD chapter duration. Shorter chapters will be ignored. */
     int                     m_oldnamescheme;                /**< @brief Use old output name scheme, can create duplicate filenames */
-    MATCHVEC*               m_include_extensions;           /**< @brief Set of extensions to include. If empty, include all. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
-    MATCHVEC*               m_hide_extensions;              /**< @brief Set of extensions to block/hide. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
+    std::unique_ptr<MATCHVEC>   m_include_extensions;           /**< @brief Set of extensions to include. If empty, include all. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
+    std::unique_ptr<MATCHVEC>   m_hide_extensions;              /**< @brief Set of extensions to block/hide. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
     // Experimental options
     int                     m_win_smb_fix;                  /**< @brief Experimental Windows fix for access to EOF at file open */
 } params;                                                   /**< @brief Command line parameters */
@@ -276,7 +271,7 @@ class thread_pool;
 /**
  * @brief Thread pool object
  */
-extern thread_pool*     tp;
+extern std::unique_ptr<thread_pool> tp;
 
 /**
  * @brief Initialise FUSE operation structure.
@@ -288,7 +283,7 @@ void            init_fuse_ops();
  * @brief Get transcoder cache path.
  * @param[out] path - Path to transcoder cache.
  */
-void            transcoder_cache_path(std::string & path);
+void            transcoder_cache_path(std::string *path);
 /**
  * @brief Initialise transcoder, create cache.
  * @return Returns true on success; false on error. Check errno for details.
