@@ -28,6 +28,7 @@
  */
 
 #include "ffmpegfs.h"
+#include "vcd/vcdchapter.h"
 #include "vcdutils.h"
 #include "ffmpeg_utils.h"
 
@@ -39,17 +40,15 @@ namespace VCDUTILS
 {
 std::string convert_txt2string(const char * txt, int size, bool trimmed)
 {
-    char * buffer = new(std::nothrow) char[static_cast<size_t>(size + 1)];
+    std::unique_ptr<char[]> buffer = std::make_unique<char[]>(static_cast<size_t>(size + 1));
     std::string ret_value;
 
     if (buffer != nullptr)
     {
-        std::memcpy(buffer, txt, static_cast<size_t>(size));
-        *(buffer + size) = '\0';
+        std::memcpy(buffer.get(), txt, static_cast<size_t>(size));
+        *(buffer.get() + size) = '\0';
 
-        ret_value = buffer;
-
-        delete [] buffer;
+        ret_value = buffer.get();
     }
 
     if (trimmed)
@@ -109,16 +108,16 @@ int locate_video(const std::string & path, int track_no, std::string & fullname)
     return ENOENT;
 }
 
-std::string get_type_str(int type)
+std::string get_type_str(VCDTYPE type)
 {
     switch (type)
     {
-    case 1:
+    case VCDTYPE::VCD_10_11_SVCD_10_HQVCD:
     {
         return "VCD 1.0, VCD 1.1, SVCD 1.0, HQVCD";
     }
 
-    case 2:
+    case VCDTYPE::VCD_20:
     {
         return "VCD 2.0";
     }
@@ -130,15 +129,15 @@ std::string get_type_str(int type)
     }
 }
 
-std::string get_profile_tag_str(int tag)
+std::string get_profile_tag_str(VCDPROFILETAG tag)
 {
     switch (tag)
     {
-    case 0:
+    case VCDPROFILETAG::VCD_10_20_SVCD_HQVCD:
     {
         return "VCD 1.0, VCD 2.0, SVCD, HQVCD";
     }
-    case 1:
+    case VCDPROFILETAG::VCD_11:
     {
         return "VCD 1.1";
     }
