@@ -36,7 +36,6 @@
 
 #include "vcdio.h"
 #include "vcd/vcdutils.h"
-#include "ffmpegfs.h"
 #include "logging.h"
 
 VcdIO::VcdIO()
@@ -57,7 +56,7 @@ VcdIO::~VcdIO()
 
 VIRTUALTYPE VcdIO::type() const
 {
-    return VIRTUALTYPE_VCD;
+    return VIRTUALTYPE::VCD;
 }
 
 size_t VcdIO::bufsize() const
