@@ -33,8 +33,6 @@
 
 #include "ffmpegfs.h"
 #include "vcdparser.h"
-#include "transcode.h"
-#include "ffmpeg_utils.h"
 #include "logging.h"
 
 #include "vcd/vcdentries.h"
@@ -67,23 +65,23 @@ static bool create_vcd_virtualfile(const VcdEntries & vcd, const struct stat * s
     {
         size = static_cast<size_t>(chapter1->get_size());
         duration = chapter1->get_duration();
-        strsprintf(&title_buf, "%02d. Chapter %03d [%s].%s", chapter1->get_track_no(), chapter_no + 1, replace_all(format_duration(duration), ":", "-").c_str(), ffmpeg_format[0].fileext().c_str()); // can safely assume this a video
+        strsprintf(&title_buf, "%02d. Chapter %03d [%s].%s", chapter1->get_track_no(), chapter_no + 1, replace_all(format_duration(duration), ":", "-").c_str(), ffmpeg_format[FORMAT::VIDEO].fileext().c_str()); // can safely assume this a video
     }
     else
     {
         size = static_cast<size_t>(vcd.get_size());
         duration = vcd.get_duration();
-        strsprintf(&title_buf, "%02d. Title [%s].%s", chapter1->get_track_no(), replace_all(format_duration(duration), ":", "-").c_str(), ffmpeg_format[0].fileext().c_str()); // can safely assume this a video
+        strsprintf(&title_buf, "%02d. Title [%s].%s", chapter1->get_track_no(), replace_all(format_duration(duration), ":", "-").c_str(), ffmpeg_format[FORMAT::VIDEO].fileext().c_str()); // can safely assume this a video
     }
 
     LPVIRTUALFILE virtualfile = nullptr;
-    if (!ffmpeg_format[0].is_multiformat())
+    if (!ffmpeg_format[FORMAT::VIDEO].is_multiformat())
     {
-        virtualfile = insert_file(VIRTUALTYPE_VCD, vcd.get_disk_path() + title_buf, statbuf);
+        virtualfile = insert_file(VIRTUALTYPE::VCD, vcd.get_disk_path() + title_buf, statbuf);
     }
     else
     {
-        virtualfile = insert_dir(VIRTUALTYPE_VCD, vcd.get_disk_path() + title_buf, statbuf);
+        virtualfile = insert_dir(VIRTUALTYPE::VCD, vcd.get_disk_path() + title_buf, statbuf);
     }
 
     if (virtualfile == nullptr)
